%define gitdate 20191102
%define rel	8
%define plugin	sc

%define dkmsname dvb-ttpci-sc_patched

%ifarch %ix86 %arm
%define parallel PARALLEL=PARALLEL_32_INT
%endif

%ifarch aarch64
%define parallel PARALLEL=PARALLEL_64_LONG
%endif

Summary:	VDR plugin: A software emulated CAM
Name:		vdr-plugin-%plugin
Version:	1.0.0
Release:	%mkrel %{?gitdate:1.git%gitdate.}%{rel}
Group:		Video/Utilities
License:	GPLv2+
URL:		https://github.com/3PO/vdr-plugin-sc
Source:		%{name}-%{gitdate}.tar.xz
BuildRequires:	vdr-devel >= 1.6.0-7
BuildRequires:	openssl-devel
BuildRequires:	pcsc-lite-devel
BuildRequires:	bzip2-devel
BuildRequires:	gettext
Requires:	vdr-abi = %vdr_abi

%description
This VDR plugin provides a software emulated CAM. Software
decryption with ffdecsa for budget cards is also available. With
this plugin you can, for example, use your pay-tv subscription with
a smart card reader/programmer without expensive CI and CAM devices.

If you use this plugin with an FF card, you will also need to use a
special version of the firmware available from the plugin home page.

This package is in tainted section because it contains algorithms
that may be covered by software patents and because its decryption
capabilities (while requiring appropriate keys) may be considered
breaking DRM.

%if 0
# Does not work, but does not seem to be needed; is doc wrong?
%package -n	dkms-%dkmsname
Summary:	DVB FF card driver patched to support vdr-sc
Group:		Video/Utilities
Requires:	dkms
Requires:	kernel-source
Requires(post):	dkms
Requires(preun):	dkms
# in non-free:
#Requires:	dvb-firmware-ttpci-sc_patched

%description -n	dkms-%dkmsname
The dvb-ttpci module which is patched to support vdr-sc. You may
need this package if you use VDR sc plugin with an FF card.

You also need the patched ttpci firmware from the package
dvb-firmware-ttpci-sc_patched.

Note that this dkms package does not work with
kernel-source-stripped packages.

This package is in PLF because it is useless without the
vdr-plugin-sc package.
%endif

%prep
%autosetup -n %{name}-%{gitdate} -p1

perl -pi -e 's,-march=,,' Makefile
%vdr_plugin_prep

%if 0
cat > patched_dvb-ttpci.sh <<EOF
#!/bin/sh -ex
KERNELDIR="\$1"
mkdir ttpci
cp \$KERNELDIR/drivers/media/dvb/ttpci/{*.[ch],Makefile} ttpci
patch -p4 -i dvb-cwidx.diff
make -C \$KERNELDIR M=\$(pwd)/ttpci modules
EOF
%endif

%vdr_plugin_params_begin %plugin
# See README for more information.
#
# forces DVB device N to budget mode (using FFdecsa)
var=FORCE_BUDGET
param=--budget=MULTIPLE_PARAMS
# external key update script
var=EXTERNAL_AU
param="-E EXTERNAL_AU"
%vdr_plugin_params_end

cat > README.0.9.0.upgrade.urpmi <<EOF
As of vdr-sc 0.9.0, the plugin expects the configuration files to
reside in the /plugins/sc subdirectory instead of /plugins. If you
are using the default configuration directory location of
/var/lib/vdr/config, you must move any SC config files from
/var/lib/vdr/config/plugins to /var/lib/vdr/config/plugins/sc.
If you do not use any configuration files with sc, you do not have
to take any action.
EOF

cat > README.0.9.2.upgrade.urpmi <<EOF
As of vdr-sc 0.9.2, smart card reader configuration has been moved
to cardslot.conf. If you have a smart card reader activated in
/etc/sysconfig/vdr-sc, you need to remove those settings and
configure the reader in /var/lib/vdr/config/plugins/sc/cardslot.conf
instead. See the example file in
/var/lib/vdr/config/plugins/sc/cardslot.conf.example.
EOF

%build
# TODO: export MAXCAID in vdr header
VDR_PLUGIN_EXTRA_FLAGS="-I%{_includedir}/PCSC -Wno-narrowing"
%vdr_plugin_build CSAFLAGS="%{vdr_plugin_flags}" %{?parallel} CPUOPT="" MAXCAID=64 HASLOCALE=1 WITH_PCSC=1 HAVE_SD=1 HAVE_HD=1 -j1

%install
%vdr_plugin_install

install -d -m755 %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}

# install some examples in-place
install -m644 examples/*.conf.example %{buildroot}%{_vdr_plugin_cfgdir}/%{plugin}

%if 0
install -d -m755 %{buildroot}/usr/src/%dkmsname-%{version}-%{release}
install -m755 patched_dvb-ttpci.sh %{buildroot}/usr/src/%dkmsname-%{version}-%{release}
install -m644 patches/dvb-cwidx.diff %{buildroot}/usr/src/%dkmsname-%{version}-%{release}

cat > %{buildroot}/usr/src/%dkmsname-%{version}-%{release}/dkms.conf <<EOF
PACKAGE_NAME="%dkmsname"
PACKAGE_VERSION="%{version}-%{release}"
MAKE[0]="./patched_dvb-ttpci.sh \$kernel_source_dir"
CLEAN="rm -rf ttpci"
AUTOINSTALL=yes
BUILT_MODULE_NAME[0]="dvb-ttpci"
BUILT_MODULE_LOCATION[0]="ttpci"
DEST_MODULE_LOCATION[0]="/kernel/drivers/media/dvb/ttpci"
EOF
%endif

%if 0
%post -n dkms-%{dkmsname}
dkms add     -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms build   -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade &&
dkms install -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade
true

%preun -n dkms-%{dkmsname}
dkms remove  -m %{dkmsname} -v %{version}-%{release} --rpm_safe_upgrade --all
true
%endif

%files -f %plugin.vdr
%doc README* HISTORY COPYING examples
%{_vdr_plugin_dir}/libsc-*.so.%vdr_apiversion
%attr(-,vdr,vdr) %dir %{_vdr_plugin_cfgdir}/%{plugin}
%{_vdr_plugin_cfgdir}/%{plugin}/*.conf.example

%if 0
%files -n dkms-%dkmsname
/usr/src/%dkmsname-%{version}-%{release}
%endif



%changelog
* Thu Jul 03 2025 umeabot <umeabot> 1.0.0-1.git20191102.8.mga10
+ Revision: 2244374
- Mageia 10 Mass Rebuild

* Fri Jun 24 2022 papoteur <papoteur> 1.0.0-1.git20191102.7.mga9.tainted
+ Revision: 1865848
- Mass Rebuild for dependencies
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ wally <wally>
- rebuild for openssl 3.0.0
- rebuild for vdr 2.4.6

* Mon Oct 26 2020 wally <wally> 1.0.0-1.git20191102.3.mga8.tainted
+ Revision: 1639682
- fix build on aarch64
- fix build on 32bit arches
- update to latest git snapshot 20191102
- update URL

* Fri Feb 21 2020 umeabot <umeabot> 1.0.0-0.hg620.9.mga8.tainted
+ Revision: 1548891
- Mageia 8 Mass Rebuild

* Sun Oct 07 2018 daviddavid <daviddavid> 1.0.0-0.hg620.8.mga7.tainted
+ Revision: 1318354
- add patch to fix compilation for kernels >= 4.14
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Wed Feb 24 2016 daviddavid <daviddavid> 1.0.0-0.hg620.7.mga6.tainted
+ Revision: 977922
- rebuild for Mageia 6

* Mon Jan 05 2015 anssi <anssi> 1.0.0-0.hg620.6.mga5.tainted
+ Revision: 808496
- rebuild with new vdr-devel with cauldron-compatible macros

* Mon Nov 24 2014 anssi <anssi> 1.0.0-0.hg620.5.mga5.tainted
+ Revision: 798677
- rebuild for new VDR
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Thu Oct 31 2013 tmb <tmb> 1.0.0-0.hg620.2.mga4.tainted
+ Revision: 548274
- Mageia 4 rebuild

* Tue Oct 15 2013 anssi <anssi> 1.0.0-0.hg620.1.mga4.tainted
+ Revision: 498526
- new snapshot

* Mon Jan 14 2013 umeabot <umeabot> 1.0.0-0.hg603.4.mga3.tainted
+ Revision: 385304
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 02 2012 malo <malo> 1.0.0-0.hg603.3.mga3.tainted
+ Revision: 325531
- update RPM group

* Wed Mar 07 2012 anssi <anssi> 1.0.0-0.hg603.2.mga2.tainted
+ Revision: 221051
- rebuild for VDR 1.7.25

* Sat Feb 25 2012 anssi <anssi> 1.0.0-0.hg603.1.mga2.tainted
+ Revision: 214841
- new snapshot (VDR 1.7.23 support)
- change includes for vdr core plugins as per our vdr-devel package
  (vdr-includes.patch)

* Sat May 14 2011 anssi <anssi> 0.9.3-2.mga1
+ Revision: 98488
- fix license tag
- drop old scriptlets
- clarify description
- dePLFify and taintify
- imported package vdr-plugin-sc


* Sun Feb 14 2010 Anssi Hannula <anssi@zarb.org> 0.9.3-1plf2010.1
- new version
- fix plugin configuration directory owned by root
- install some configuration file examples into the configuration directory

* Tue Jul 28 2009 Anssi Hannula <anssi@zarb.org> 0.9.2-1plf2010.0
- new version
- update sysconfig file
- provide (empty) sc configuration directory
- add README.0.9.2.upgrade.urpmi for configuration changes
- build with pcsc-lite support
- buildrequires bzip2-devel

* Fri Mar 27 2009 Anssi Hannula <anssi@zarb.org> 0.9.0-4plf2009.1
- rebuild for new vdr

* Tue Apr 29 2008 Anssi Hannula <anssi@zarb.org> 0.9.0-3plf2009.0
- rebuild for new vdr

* Fri Apr 25 2008 Anssi Hannula <anssi@zarb.org> 0.9.0-2plf2009.0
- rebuild for VDR 1.6.0
- drop the apparently unneeded dkms package

* Fri Feb 29 2008 Anssi Hannula <anssi@zarb.org> 0.9.0-1plf2008.1
- new version
- add README.0.9.0.upgrade.urpmi for changes

* Fri Jan 04 2008 Anssi Hannula <anssi@zarb.org> 0.8.1-4plf2008.1
- use MULTIPLE_PARAMS for sysconfig file

* Mon Oct 29 2007 Anssi Hannula <anssi@zarb.org> 0.8.1-3plf2008.1
- rebuild for new vdr

* Tue Jul 10 2007 Anssi Hannula <anssi@zarb.org> 0.8.1-2plf2008.0
- remove hardcoded compiler flags

* Mon Jul 09 2007 Anssi Hannula <anssi@zarb.org> 0.8.1-1plf2008.0
- 0.8.1
- buildrequires new vdr
- fix typo in TIMEOUT_SECS sysconfig variable handling
- add FORCE_BUDGET option into sysconfig file
- drop patch0, no longer needed
- require full kernel-source in dkms subpackage
- force non-zero exit status in post and preun of dkms subpackage

* Thu Jun 21 2007 Anssi Hannula <anssi@zarb.org> 0.6.2-3plf2008.0
- rebuild for new vdr

* Sat May 05 2007 Anssi Hannula <anssi@zarb.org> 0.6.2-2plf2008.0
- rebuild for new vdr

* Sat Apr 28 2007 Anssi Hannula <anssi@zarb.org> 0.6.2-1plf2008.0
- 0.6.2
- do not require packages from non-free
- rediff patch0

* Sun Dec 10 2006 Anssi Hannula <anssi@zarb.org> 0.5.11-2plf2007.0
- rebuild for new vdr

* Tue Oct 31 2006 Anssi Hannula <anssi@mandriva.org> 0.5.11-1plf2007.0
- 0.5.11

* Tue Sep 03 2006 Anssi Hannula <anssi@mandriva.org> 0.5.10-1plf2007.0
- initial PLF release
